@@ -6,7 +6,7 @@ package Lingua::Translit::Tables;
 #   Alex Linke, <alinke@lingua-systems.com>
 #   Rona Linke, <rlinke@lingua-systems.com>
 #
-# $Id: Tables.pm 258 2008-04-22 14:54:18Z alinke $
+# $Id: Tables.pm 275 2008-04-29 07:57:47Z alinke $
 #
 
 
@@ -16,7 +16,7 @@ use warnings;
 require 5.008;
 
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 
 use utf8;
@@ -170,44 +170,51 @@ sub translit_list_supported
 
 =over 4
 
-=item B<ISO 843>, not reversible, C<ISO 843:1997, Greek to Latin>
+=item Cyrillic
 
-=item B<ISO 9>, reversible, C<ISO 9:1995, Cyrillic to Latin>
+I<ISO 9>, reversible, ISO 9:1995, Cyrillic to Latin
 
-=item B<Greeklish>, not reversible, C<Greeklish (Phonetic), Greek to Latin>
+I<Streamlined System BUL>, not reversible, The Streamlined System: 2006,
+Cyrillic to Latin, Bulgarian
 
-=item B<DIN 31634>, not reversible, C<DIN 31634:1982, Greek to Latin>
+I<DIN 1460 BUL>, reversible, DIN 1460:1982, Cyrillic to Latin, Bulgarian
 
-=item B<DIN 1460 BUL>, reversible, C<DIN 1460:1982, Cyrillic to Latin, Bulgarian>
+=item Greek
 
-=item B<Common RON>, not reversible, C<Romanian without diacritics as commonly used>
+I<ISO 843>, not reversible, ISO 843:1997, Greek to Latin
 
-=item B<Common DEU>, not reversible, C<German without umlauts>
+I<DIN 31634>, not reversible, DIN 31634:1982, Greek to Latin
 
-=item B<Common CES>, not reversible, C<Czech without diacritics>
+I<Greeklish>, not reversible, Greeklish (Phonetic), Greek to Latin
 
-=item B<Common POL>, not reversible, C<Unaccented Polish>
+=item Latin
 
-=item B<Common Classical MON>, reversible, C<Classical Mongolian to Latin>
+I<Common CES>, not reversible, Czech without diacritics
 
-=item B<Streamlined System BUL>, not reversible, C<The Streamlined System: 2006, Cyrillic to Latin, Bulgarian>
+I<Common DEU>, not reversible, German without umlauts
 
-=item B<Common SLV>, not reversible, C<Slovenian without diacritics>
+I<Common POL>, not reversible, Unaccented Polish
 
-=item B<Common SLK>, not reversible, C<Slovak without diacritics>
+I<Common RON>, not reversible, Romanian without diacritics as commonly used
+
+I<Common SLK>, not reversible, Slovak without diacritics
+
+I<Common SLV>, not reversible, Slovenian without diacritics
+
+=item Mongolian
+
+I<Common Classical MON>, reversible, Classical Mongolian to Latin
 
 =back
 
-=head1 EXTENDING
+=head1 ADDING NEW TRANSLITERATIONS
 
-If you want to extend the list of supported transliterations, have a look at
-the F<xml/> directory within the distribution tarball.  It contains XML
-definitions of transliteration tables and a template file F<template> you may
-want to use and B<xml2dump>, a tool to convert these into the proper format as
-used by L<Lingua::Translit::Tables>.
+In case you want to add your own transliteration tables to L<Lingua::Translit>,
+a developer manual (F<xml/manual/>) is available in HTML and plain text format.
+An online version is available at
+L<http://www.lingua-systems.com/products/translit/manual/>.
 
-Contact the authors at perl@lingua-systems.com if you feel the desire to
-contribute your table to the official distribution.
+All necessary tools and templates to start with are provided as well.
 
 =head1 BUGS
 
